# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: minknow/rpc/acquisition.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='minknow/rpc/acquisition.proto',
  package='ont.rpc.acquisition',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1dminknow/rpc/acquisition.proto\x12\x13ont.rpc.acquisition\x1a\x1fgoogle/protobuf/timestamp.proto\"\x99\x03\n\x0cStartRequest\x12\x1d\n\x15wait_until_processing\x18\x01 \x01(\x08\x12\"\n\x1a\x64ont_wait_for_device_ready\x18\x02 \x01(\x08\x12\x34\n\x0fgenerate_report\x18\x03 \x01(\x0e\x32\x1b.ont.rpc.acquisition.Option\x12\x41\n\x1csend_sequencing_read_metrics\x18\x04 \x01(\x0e\x32\x1b.ont.rpc.acquisition.Option\x12=\n\x18send_basecalling_metrics\x18\x05 \x01(\x0e\x32\x1b.ont.rpc.acquisition.Option\x12-\n\x07purpose\x18\x06 \x01(\x0e\x32\x1c.ont.rpc.acquisition.Purpose\x12-\n\x08\x61nalysis\x18\x07 \x01(\x0e\x32\x1b.ont.rpc.acquisition.Option\x12\x30\n\x0b\x66ile_output\x18\x08 \x01(\x0e\x32\x1b.ont.rpc.acquisition.Option\"\x1f\n\rStartResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\xdc\x01\n\x0bStopRequest\x12H\n\x13\x64\x61ta_action_on_stop\x18\x01 \x01(\x0e\x32+.ont.rpc.acquisition.StopRequest.DataAction\x12\x18\n\x10wait_until_ready\x18\x02 \x01(\x08\x12\x15\n\rkeep_power_on\x18\x03 \x01(\x08\"R\n\nDataAction\x12\x10\n\x0cSTOP_DEFAULT\x10\x00\x12\x16\n\x12STOP_KEEP_ALL_DATA\x10\x01\x12\x1a\n\x16STOP_FINISH_PROCESSING\x10\x02\"\x0e\n\x0cStopResponse\"+\n\x1bWatchForStatusChangeRequest\x12\x0c\n\x04stop\x18\x01 \x01(\x08\"R\n\x1cWatchForStatusChangeResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ont.rpc.acquisition.MinknowStatus\"\x16\n\x14\x43urrentStatusRequest\"K\n\x15\x43urrentStatusResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ont.rpc.acquisition.MinknowStatus\"\x14\n\x12GetProgressRequest\"\x9c\x01\n\x13GetProgressResponse\x12O\n\x0fraw_per_channel\x18\x01 \x01(\x0b\x32\x36.ont.rpc.acquisition.GetProgressResponse.RawPerChannel\x1a\x34\n\rRawPerChannel\x12\x10\n\x08\x61\x63quired\x18\x01 \x01(\x04\x12\x11\n\tprocessed\x18\x02 \x01(\x04\".\n\x1cGetAcquisitionRunInfoRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\xa9\x03\n\x17\x41\x63quisitionYieldSummary\x12\x12\n\nread_count\x18\x01 \x01(\x03\x12\x1a\n\x12written_read_count\x18\x02 \x01(\x03\x12\"\n\x1a\x62\x61secalled_pass_read_count\x18\x03 \x01(\x03\x12\"\n\x1a\x62\x61secalled_fail_read_count\x18\x04 \x01(\x03\x12%\n\x1d\x62\x61secalled_skipped_read_count\x18\n \x01(\x03\x12\x18\n\x10\x62\x61secalled_bases\x18\x05 \x01(\x03\x12\x1a\n\x12\x62\x61secalled_samples\x18\x06 \x01(\x03\x12\x1c\n\x14selected_raw_samples\x18\x07 \x01(\x03\x12\x17\n\x0fselected_events\x18\x08 \x01(\x03\x12 \n\x18\x65stimated_selected_bases\x18\t \x01(\x03\x12\x1f\n\x17\x62ytes_to_write_produced\x18\x0b \x01(\x03\x12\x1d\n\x15\x62ytes_to_write_failed\x18\x0c \x01(\x03\x12 \n\x18\x62ytes_to_write_completed\x18\r \x01(\x03\"\xa0\x03\n\x10\x43hannelStateInfo\x12;\n\x06groups\x18\x01 \x03(\x0b\x32+.ont.rpc.acquisition.ChannelStateInfo.Group\x1a;\n\x05Style\x12\r\n\x05label\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x63olour\x18\x03 \x01(\t\x1az\n\x0c\x43hannelState\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x05style\x18\x03 \x01(\x0b\x32+.ont.rpc.acquisition.ChannelStateInfo.Style\x12\x14\n\x0cglobal_order\x18\x04 \x01(\r\x1a\x95\x01\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x05style\x18\x02 \x01(\x0b\x32+.ont.rpc.acquisition.ChannelStateInfo.Style\x12\x42\n\x06states\x18\x03 \x03(\x0b\x32\x32.ont.rpc.acquisition.ChannelStateInfo.ChannelState\"\x8e\x03\n\x18\x41\x63quisitionConfigSummary\x12\x1b\n\x13\x62\x61secalling_enabled\x18\x01 \x01(\x08\x12\x17\n\x0freads_directory\x18\x02 \x01(\t\x12\"\n\x1areads_fallback_directories\x18\x03 \x03(\t\x12\x1b\n\x13\x66\x61st5_reads_enabled\x18\x04 \x01(\x08\x12\x1b\n\x13\x66\x61stq_reads_enabled\x18\x05 \x01(\x08\x12\x1e\n\x16protobuf_reads_enabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x62ulk_file_path\x18\x07 \x01(\t\x12\x19\n\x11\x62ulk_file_enabled\x18\x08 \x01(\x08\x12\x41\n\x12\x63hannel_state_info\x18\t \x01(\x0b\x32%.ont.rpc.acquisition.ChannelStateInfo\x12\x1c\n\x14\x65vents_to_base_ratio\x18\n \x01(\x02\x12\x13\n\x0bsample_rate\x18\x0b \x01(\r\x12\x15\n\rchannel_count\x18\x0c \x01(\r\"\xb5\x04\n\x12\x41\x63quisitionRunInfo\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x34\n\x05state\x18\x02 \x01(\x0e\x32%.ont.rpc.acquisition.AcquisitionState\x12<\n\x0f\x66inishing_state\x18\n \x01(\x0e\x32#.ont.rpc.acquisition.FinishingState\x12?\n\x0bstop_reason\x18\x03 \x01(\x0e\x32*.ont.rpc.acquisition.AcquisitionStopReason\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14\x64\x61ta_read_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x64\x61ta_read_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\ryield_summary\x18\x08 \x01(\x0b\x32,.ont.rpc.acquisition.AcquisitionYieldSummary\x12\x45\n\x0e\x63onfig_summary\x18\t \x01(\x0b\x32-.ont.rpc.acquisition.AcquisitionConfigSummary\"\x1c\n\x1aListAcquisitionRunsRequest\".\n\x1bListAcquisitionRunsResponse\x12\x0f\n\x07run_ids\x18\x01 \x03(\t\"!\n\x1fGetCurrentAcquisitionRunRequest\"#\n!WatchCurrentAcquisitionRunRequest*Y\n\rMinknowStatus\x12\x10\n\x0c\x45RROR_STATUS\x10\x00\x12\t\n\x05READY\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0e\n\nPROCESSING\x10\x03\x12\r\n\tFINISHING\x10\x04**\n\x06Option\x12\x08\n\x04\x41UTO\x10\x00\x12\x0b\n\x07\x44ISABLE\x10\x01\x12\t\n\x05\x46ORCE\x10\x02*=\n\x07Purpose\x12\x11\n\rOTHER_PURPOSE\x10\x00\x12\x0e\n\nSEQUENCING\x10\x02\x12\x0f\n\x0b\x43\x41LIBRATION\x10\x03*{\n\x10\x41\x63quisitionState\x12\x18\n\x14\x41\x43QUISITION_STARTING\x10\x00\x12\x17\n\x13\x41\x43QUISITION_RUNNING\x10\x01\x12\x19\n\x15\x41\x43QUISITION_FINISHING\x10\x02\x12\x19\n\x15\x41\x43QUISITION_COMPLETED\x10\x03*\xe3\x01\n\x15\x41\x63quisitionStopReason\x12\x13\n\x0fSTOPPED_NOT_SET\x10\x00\x12\x1a\n\x16STOPPED_USER_REQUESTED\x10\x01\x12\x19\n\x15STOPPED_NO_DISK_SPACE\x10\x02\x12&\n\"STOPPED_DEVICE_STOPPED_ACQUISITION\x10\x03\x12 \n\x1cSTOPPED_STARTING_ANOTHER_RUN\x10\x04\x12\x1a\n\x16STOPPED_PROTOCOL_ENDED\x10\x05\x12\x18\n\x14STOPPED_DEVICE_ERROR\x10\x06*\x8b\x01\n\x0e\x46inishingState\x12\x15\n\x11\x46INISHING_UNKNOWN\x10\x00\x12&\n\"FINISHING_PROCESSING_DEVICE_SIGNAL\x10\x01\x12\x1f\n\x1b\x46INISHING_BASECALLING_READS\x10\x02\x12\x19\n\x15\x46INISHING_SAVING_DATA\x10\x03\x32\x87\x08\n\x12\x41\x63quisitionService\x12P\n\x05start\x12!.ont.rpc.acquisition.StartRequest\x1a\".ont.rpc.acquisition.StartResponse\"\x00\x12M\n\x04stop\x12 .ont.rpc.acquisition.StopRequest\x1a!.ont.rpc.acquisition.StopResponse\"\x00\x12\x84\x01\n\x17watch_for_status_change\x12\x30.ont.rpc.acquisition.WatchForStatusChangeRequest\x1a\x31.ont.rpc.acquisition.WatchForStatusChangeResponse\"\x00(\x01\x30\x01\x12\x84\x01\n\x1dwatch_current_acquisition_run\x12\x36.ont.rpc.acquisition.WatchCurrentAcquisitionRunRequest\x1a\'.ont.rpc.acquisition.AcquisitionRunInfo\"\x00\x30\x01\x12i\n\x0e\x63urrent_status\x12).ont.rpc.acquisition.CurrentStatusRequest\x1a*.ont.rpc.acquisition.CurrentStatusResponse\"\x00\x12\x63\n\x0cget_progress\x12\'.ont.rpc.acquisition.GetProgressRequest\x1a(.ont.rpc.acquisition.GetProgressResponse\"\x00\x12t\n\x14get_acquisition_info\x12\x31.ont.rpc.acquisition.GetAcquisitionRunInfoRequest\x1a\'.ont.rpc.acquisition.AcquisitionRunInfo\"\x00\x12|\n\x15list_acquisition_runs\x12/.ont.rpc.acquisition.ListAcquisitionRunsRequest\x1a\x30.ont.rpc.acquisition.ListAcquisitionRunsResponse\"\x00\x12~\n\x1bget_current_acquisition_run\x12\x34.ont.rpc.acquisition.GetCurrentAcquisitionRunRequest\x1a\'.ont.rpc.acquisition.AcquisitionRunInfo\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_MINKNOWSTATUS = _descriptor.EnumDescriptor(
  name='MinknowStatus',
  full_name='ont.rpc.acquisition.MinknowStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR_STATUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHING', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3196,
  serialized_end=3285,
)
_sym_db.RegisterEnumDescriptor(_MINKNOWSTATUS)

MinknowStatus = enum_type_wrapper.EnumTypeWrapper(_MINKNOWSTATUS)
_OPTION = _descriptor.EnumDescriptor(
  name='Option',
  full_name='ont.rpc.acquisition.Option',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORCE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3287,
  serialized_end=3329,
)
_sym_db.RegisterEnumDescriptor(_OPTION)

Option = enum_type_wrapper.EnumTypeWrapper(_OPTION)
_PURPOSE = _descriptor.EnumDescriptor(
  name='Purpose',
  full_name='ont.rpc.acquisition.Purpose',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OTHER_PURPOSE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEQUENCING', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALIBRATION', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3331,
  serialized_end=3392,
)
_sym_db.RegisterEnumDescriptor(_PURPOSE)

Purpose = enum_type_wrapper.EnumTypeWrapper(_PURPOSE)
_ACQUISITIONSTATE = _descriptor.EnumDescriptor(
  name='AcquisitionState',
  full_name='ont.rpc.acquisition.AcquisitionState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACQUISITION_STARTING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACQUISITION_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACQUISITION_FINISHING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACQUISITION_COMPLETED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3394,
  serialized_end=3517,
)
_sym_db.RegisterEnumDescriptor(_ACQUISITIONSTATE)

AcquisitionState = enum_type_wrapper.EnumTypeWrapper(_ACQUISITIONSTATE)
_ACQUISITIONSTOPREASON = _descriptor.EnumDescriptor(
  name='AcquisitionStopReason',
  full_name='ont.rpc.acquisition.AcquisitionStopReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOPPED_NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_USER_REQUESTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_NO_DISK_SPACE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_DEVICE_STOPPED_ACQUISITION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_STARTING_ANOTHER_RUN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_PROTOCOL_ENDED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_DEVICE_ERROR', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3520,
  serialized_end=3747,
)
_sym_db.RegisterEnumDescriptor(_ACQUISITIONSTOPREASON)

AcquisitionStopReason = enum_type_wrapper.EnumTypeWrapper(_ACQUISITIONSTOPREASON)
_FINISHINGSTATE = _descriptor.EnumDescriptor(
  name='FinishingState',
  full_name='ont.rpc.acquisition.FinishingState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FINISHING_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHING_PROCESSING_DEVICE_SIGNAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHING_BASECALLING_READS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHING_SAVING_DATA', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3750,
  serialized_end=3889,
)
_sym_db.RegisterEnumDescriptor(_FINISHINGSTATE)

FinishingState = enum_type_wrapper.EnumTypeWrapper(_FINISHINGSTATE)
ERROR_STATUS = 0
READY = 1
STARTING = 2
PROCESSING = 3
FINISHING = 4
AUTO = 0
DISABLE = 1
FORCE = 2
OTHER_PURPOSE = 0
SEQUENCING = 2
CALIBRATION = 3
ACQUISITION_STARTING = 0
ACQUISITION_RUNNING = 1
ACQUISITION_FINISHING = 2
ACQUISITION_COMPLETED = 3
STOPPED_NOT_SET = 0
STOPPED_USER_REQUESTED = 1
STOPPED_NO_DISK_SPACE = 2
STOPPED_DEVICE_STOPPED_ACQUISITION = 3
STOPPED_STARTING_ANOTHER_RUN = 4
STOPPED_PROTOCOL_ENDED = 5
STOPPED_DEVICE_ERROR = 6
FINISHING_UNKNOWN = 0
FINISHING_PROCESSING_DEVICE_SIGNAL = 1
FINISHING_BASECALLING_READS = 2
FINISHING_SAVING_DATA = 3


_STOPREQUEST_DATAACTION = _descriptor.EnumDescriptor(
  name='DataAction',
  full_name='ont.rpc.acquisition.StopRequest.DataAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOP_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_KEEP_ALL_DATA', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_FINISH_PROCESSING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=671,
  serialized_end=753,
)
_sym_db.RegisterEnumDescriptor(_STOPREQUEST_DATAACTION)


_STARTREQUEST = _descriptor.Descriptor(
  name='StartRequest',
  full_name='ont.rpc.acquisition.StartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait_until_processing', full_name='ont.rpc.acquisition.StartRequest.wait_until_processing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dont_wait_for_device_ready', full_name='ont.rpc.acquisition.StartRequest.dont_wait_for_device_ready', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generate_report', full_name='ont.rpc.acquisition.StartRequest.generate_report', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_sequencing_read_metrics', full_name='ont.rpc.acquisition.StartRequest.send_sequencing_read_metrics', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_basecalling_metrics', full_name='ont.rpc.acquisition.StartRequest.send_basecalling_metrics', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purpose', full_name='ont.rpc.acquisition.StartRequest.purpose', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='ont.rpc.acquisition.StartRequest.analysis', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_output', full_name='ont.rpc.acquisition.StartRequest.file_output', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=497,
)


_STARTRESPONSE = _descriptor.Descriptor(
  name='StartResponse',
  full_name='ont.rpc.acquisition.StartResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='ont.rpc.acquisition.StartResponse.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=530,
)


_STOPREQUEST = _descriptor.Descriptor(
  name='StopRequest',
  full_name='ont.rpc.acquisition.StopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_action_on_stop', full_name='ont.rpc.acquisition.StopRequest.data_action_on_stop', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_until_ready', full_name='ont.rpc.acquisition.StopRequest.wait_until_ready', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_power_on', full_name='ont.rpc.acquisition.StopRequest.keep_power_on', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STOPREQUEST_DATAACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=753,
)


_STOPRESPONSE = _descriptor.Descriptor(
  name='StopResponse',
  full_name='ont.rpc.acquisition.StopResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=769,
)


_WATCHFORSTATUSCHANGEREQUEST = _descriptor.Descriptor(
  name='WatchForStatusChangeRequest',
  full_name='ont.rpc.acquisition.WatchForStatusChangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop', full_name='ont.rpc.acquisition.WatchForStatusChangeRequest.stop', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=814,
)


_WATCHFORSTATUSCHANGERESPONSE = _descriptor.Descriptor(
  name='WatchForStatusChangeResponse',
  full_name='ont.rpc.acquisition.WatchForStatusChangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ont.rpc.acquisition.WatchForStatusChangeResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=898,
)


_CURRENTSTATUSREQUEST = _descriptor.Descriptor(
  name='CurrentStatusRequest',
  full_name='ont.rpc.acquisition.CurrentStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=922,
)


_CURRENTSTATUSRESPONSE = _descriptor.Descriptor(
  name='CurrentStatusResponse',
  full_name='ont.rpc.acquisition.CurrentStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ont.rpc.acquisition.CurrentStatusResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=999,
)


_GETPROGRESSREQUEST = _descriptor.Descriptor(
  name='GetProgressRequest',
  full_name='ont.rpc.acquisition.GetProgressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1021,
)


_GETPROGRESSRESPONSE_RAWPERCHANNEL = _descriptor.Descriptor(
  name='RawPerChannel',
  full_name='ont.rpc.acquisition.GetProgressResponse.RawPerChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acquired', full_name='ont.rpc.acquisition.GetProgressResponse.RawPerChannel.acquired', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processed', full_name='ont.rpc.acquisition.GetProgressResponse.RawPerChannel.processed', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1180,
)

_GETPROGRESSRESPONSE = _descriptor.Descriptor(
  name='GetProgressResponse',
  full_name='ont.rpc.acquisition.GetProgressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_per_channel', full_name='ont.rpc.acquisition.GetProgressResponse.raw_per_channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETPROGRESSRESPONSE_RAWPERCHANNEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1180,
)


_GETACQUISITIONRUNINFOREQUEST = _descriptor.Descriptor(
  name='GetAcquisitionRunInfoRequest',
  full_name='ont.rpc.acquisition.GetAcquisitionRunInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='ont.rpc.acquisition.GetAcquisitionRunInfoRequest.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1228,
)


_ACQUISITIONYIELDSUMMARY = _descriptor.Descriptor(
  name='AcquisitionYieldSummary',
  full_name='ont.rpc.acquisition.AcquisitionYieldSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_count', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.read_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='written_read_count', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.written_read_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basecalled_pass_read_count', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.basecalled_pass_read_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basecalled_fail_read_count', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.basecalled_fail_read_count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basecalled_skipped_read_count', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.basecalled_skipped_read_count', index=4,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basecalled_bases', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.basecalled_bases', index=5,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basecalled_samples', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.basecalled_samples', index=6,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selected_raw_samples', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.selected_raw_samples', index=7,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selected_events', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.selected_events', index=8,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimated_selected_bases', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.estimated_selected_bases', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_to_write_produced', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.bytes_to_write_produced', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_to_write_failed', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.bytes_to_write_failed', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_to_write_completed', full_name='ont.rpc.acquisition.AcquisitionYieldSummary.bytes_to_write_completed', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1656,
)


_CHANNELSTATEINFO_STYLE = _descriptor.Descriptor(
  name='Style',
  full_name='ont.rpc.acquisition.ChannelStateInfo.Style',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='ont.rpc.acquisition.ChannelStateInfo.Style.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='ont.rpc.acquisition.ChannelStateInfo.Style.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='colour', full_name='ont.rpc.acquisition.ChannelStateInfo.Style.colour', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1799,
)

_CHANNELSTATEINFO_CHANNELSTATE = _descriptor.Descriptor(
  name='ChannelState',
  full_name='ont.rpc.acquisition.ChannelStateInfo.ChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ont.rpc.acquisition.ChannelStateInfo.ChannelState.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.acquisition.ChannelStateInfo.ChannelState.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='ont.rpc.acquisition.ChannelStateInfo.ChannelState.style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_order', full_name='ont.rpc.acquisition.ChannelStateInfo.ChannelState.global_order', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1801,
  serialized_end=1923,
)

_CHANNELSTATEINFO_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='ont.rpc.acquisition.ChannelStateInfo.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.acquisition.ChannelStateInfo.Group.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='ont.rpc.acquisition.ChannelStateInfo.Group.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='states', full_name='ont.rpc.acquisition.ChannelStateInfo.Group.states', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1926,
  serialized_end=2075,
)

_CHANNELSTATEINFO = _descriptor.Descriptor(
  name='ChannelStateInfo',
  full_name='ont.rpc.acquisition.ChannelStateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='ont.rpc.acquisition.ChannelStateInfo.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELSTATEINFO_STYLE, _CHANNELSTATEINFO_CHANNELSTATE, _CHANNELSTATEINFO_GROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=2075,
)


_ACQUISITIONCONFIGSUMMARY = _descriptor.Descriptor(
  name='AcquisitionConfigSummary',
  full_name='ont.rpc.acquisition.AcquisitionConfigSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='basecalling_enabled', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.basecalling_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reads_directory', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.reads_directory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reads_fallback_directories', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.reads_fallback_directories', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fast5_reads_enabled', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.fast5_reads_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fastq_reads_enabled', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.fastq_reads_enabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protobuf_reads_enabled', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.protobuf_reads_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bulk_file_path', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.bulk_file_path', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bulk_file_enabled', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.bulk_file_enabled', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_state_info', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.channel_state_info', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events_to_base_ratio', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.events_to_base_ratio', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.sample_rate', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_count', full_name='ont.rpc.acquisition.AcquisitionConfigSummary.channel_count', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2476,
)


_ACQUISITIONRUNINFO = _descriptor.Descriptor(
  name='AcquisitionRunInfo',
  full_name='ont.rpc.acquisition.AcquisitionRunInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='ont.rpc.acquisition.AcquisitionRunInfo.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ont.rpc.acquisition.AcquisitionRunInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finishing_state', full_name='ont.rpc.acquisition.AcquisitionRunInfo.finishing_state', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_reason', full_name='ont.rpc.acquisition.AcquisitionRunInfo.stop_reason', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='ont.rpc.acquisition.AcquisitionRunInfo.start_time', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_read_start_time', full_name='ont.rpc.acquisition.AcquisitionRunInfo.data_read_start_time', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_read_end_time', full_name='ont.rpc.acquisition.AcquisitionRunInfo.data_read_end_time', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='ont.rpc.acquisition.AcquisitionRunInfo.end_time', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yield_summary', full_name='ont.rpc.acquisition.AcquisitionRunInfo.yield_summary', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_summary', full_name='ont.rpc.acquisition.AcquisitionRunInfo.config_summary', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2479,
  serialized_end=3044,
)


_LISTACQUISITIONRUNSREQUEST = _descriptor.Descriptor(
  name='ListAcquisitionRunsRequest',
  full_name='ont.rpc.acquisition.ListAcquisitionRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3046,
  serialized_end=3074,
)


_LISTACQUISITIONRUNSRESPONSE = _descriptor.Descriptor(
  name='ListAcquisitionRunsResponse',
  full_name='ont.rpc.acquisition.ListAcquisitionRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_ids', full_name='ont.rpc.acquisition.ListAcquisitionRunsResponse.run_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3122,
)


_GETCURRENTACQUISITIONRUNREQUEST = _descriptor.Descriptor(
  name='GetCurrentAcquisitionRunRequest',
  full_name='ont.rpc.acquisition.GetCurrentAcquisitionRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3124,
  serialized_end=3157,
)


_WATCHCURRENTACQUISITIONRUNREQUEST = _descriptor.Descriptor(
  name='WatchCurrentAcquisitionRunRequest',
  full_name='ont.rpc.acquisition.WatchCurrentAcquisitionRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3159,
  serialized_end=3194,
)

_STARTREQUEST.fields_by_name['generate_report'].enum_type = _OPTION
_STARTREQUEST.fields_by_name['send_sequencing_read_metrics'].enum_type = _OPTION
_STARTREQUEST.fields_by_name['send_basecalling_metrics'].enum_type = _OPTION
_STARTREQUEST.fields_by_name['purpose'].enum_type = _PURPOSE
_STARTREQUEST.fields_by_name['analysis'].enum_type = _OPTION
_STARTREQUEST.fields_by_name['file_output'].enum_type = _OPTION
_STOPREQUEST.fields_by_name['data_action_on_stop'].enum_type = _STOPREQUEST_DATAACTION
_STOPREQUEST_DATAACTION.containing_type = _STOPREQUEST
_WATCHFORSTATUSCHANGERESPONSE.fields_by_name['status'].enum_type = _MINKNOWSTATUS
_CURRENTSTATUSRESPONSE.fields_by_name['status'].enum_type = _MINKNOWSTATUS
_GETPROGRESSRESPONSE_RAWPERCHANNEL.containing_type = _GETPROGRESSRESPONSE
_GETPROGRESSRESPONSE.fields_by_name['raw_per_channel'].message_type = _GETPROGRESSRESPONSE_RAWPERCHANNEL
_CHANNELSTATEINFO_STYLE.containing_type = _CHANNELSTATEINFO
_CHANNELSTATEINFO_CHANNELSTATE.fields_by_name['style'].message_type = _CHANNELSTATEINFO_STYLE
_CHANNELSTATEINFO_CHANNELSTATE.containing_type = _CHANNELSTATEINFO
_CHANNELSTATEINFO_GROUP.fields_by_name['style'].message_type = _CHANNELSTATEINFO_STYLE
_CHANNELSTATEINFO_GROUP.fields_by_name['states'].message_type = _CHANNELSTATEINFO_CHANNELSTATE
_CHANNELSTATEINFO_GROUP.containing_type = _CHANNELSTATEINFO
_CHANNELSTATEINFO.fields_by_name['groups'].message_type = _CHANNELSTATEINFO_GROUP
_ACQUISITIONCONFIGSUMMARY.fields_by_name['channel_state_info'].message_type = _CHANNELSTATEINFO
_ACQUISITIONRUNINFO.fields_by_name['state'].enum_type = _ACQUISITIONSTATE
_ACQUISITIONRUNINFO.fields_by_name['finishing_state'].enum_type = _FINISHINGSTATE
_ACQUISITIONRUNINFO.fields_by_name['stop_reason'].enum_type = _ACQUISITIONSTOPREASON
_ACQUISITIONRUNINFO.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACQUISITIONRUNINFO.fields_by_name['data_read_start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACQUISITIONRUNINFO.fields_by_name['data_read_end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACQUISITIONRUNINFO.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACQUISITIONRUNINFO.fields_by_name['yield_summary'].message_type = _ACQUISITIONYIELDSUMMARY
_ACQUISITIONRUNINFO.fields_by_name['config_summary'].message_type = _ACQUISITIONCONFIGSUMMARY
DESCRIPTOR.message_types_by_name['StartRequest'] = _STARTREQUEST
DESCRIPTOR.message_types_by_name['StartResponse'] = _STARTRESPONSE
DESCRIPTOR.message_types_by_name['StopRequest'] = _STOPREQUEST
DESCRIPTOR.message_types_by_name['StopResponse'] = _STOPRESPONSE
DESCRIPTOR.message_types_by_name['WatchForStatusChangeRequest'] = _WATCHFORSTATUSCHANGEREQUEST
DESCRIPTOR.message_types_by_name['WatchForStatusChangeResponse'] = _WATCHFORSTATUSCHANGERESPONSE
DESCRIPTOR.message_types_by_name['CurrentStatusRequest'] = _CURRENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['CurrentStatusResponse'] = _CURRENTSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetProgressRequest'] = _GETPROGRESSREQUEST
DESCRIPTOR.message_types_by_name['GetProgressResponse'] = _GETPROGRESSRESPONSE
DESCRIPTOR.message_types_by_name['GetAcquisitionRunInfoRequest'] = _GETACQUISITIONRUNINFOREQUEST
DESCRIPTOR.message_types_by_name['AcquisitionYieldSummary'] = _ACQUISITIONYIELDSUMMARY
DESCRIPTOR.message_types_by_name['ChannelStateInfo'] = _CHANNELSTATEINFO
DESCRIPTOR.message_types_by_name['AcquisitionConfigSummary'] = _ACQUISITIONCONFIGSUMMARY
DESCRIPTOR.message_types_by_name['AcquisitionRunInfo'] = _ACQUISITIONRUNINFO
DESCRIPTOR.message_types_by_name['ListAcquisitionRunsRequest'] = _LISTACQUISITIONRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListAcquisitionRunsResponse'] = _LISTACQUISITIONRUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetCurrentAcquisitionRunRequest'] = _GETCURRENTACQUISITIONRUNREQUEST
DESCRIPTOR.message_types_by_name['WatchCurrentAcquisitionRunRequest'] = _WATCHCURRENTACQUISITIONRUNREQUEST
DESCRIPTOR.enum_types_by_name['MinknowStatus'] = _MINKNOWSTATUS
DESCRIPTOR.enum_types_by_name['Option'] = _OPTION
DESCRIPTOR.enum_types_by_name['Purpose'] = _PURPOSE
DESCRIPTOR.enum_types_by_name['AcquisitionState'] = _ACQUISITIONSTATE
DESCRIPTOR.enum_types_by_name['AcquisitionStopReason'] = _ACQUISITIONSTOPREASON
DESCRIPTOR.enum_types_by_name['FinishingState'] = _FINISHINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StartRequest = _reflection.GeneratedProtocolMessageType('StartRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.StartRequest)
  })
_sym_db.RegisterMessage(StartRequest)

StartResponse = _reflection.GeneratedProtocolMessageType('StartResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTRESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.StartResponse)
  })
_sym_db.RegisterMessage(StartResponse)

StopRequest = _reflection.GeneratedProtocolMessageType('StopRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.StopRequest)
  })
_sym_db.RegisterMessage(StopRequest)

StopResponse = _reflection.GeneratedProtocolMessageType('StopResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPRESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.StopResponse)
  })
_sym_db.RegisterMessage(StopResponse)

WatchForStatusChangeRequest = _reflection.GeneratedProtocolMessageType('WatchForStatusChangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHFORSTATUSCHANGEREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.WatchForStatusChangeRequest)
  })
_sym_db.RegisterMessage(WatchForStatusChangeRequest)

WatchForStatusChangeResponse = _reflection.GeneratedProtocolMessageType('WatchForStatusChangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHFORSTATUSCHANGERESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.WatchForStatusChangeResponse)
  })
_sym_db.RegisterMessage(WatchForStatusChangeResponse)

CurrentStatusRequest = _reflection.GeneratedProtocolMessageType('CurrentStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTSTATUSREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.CurrentStatusRequest)
  })
_sym_db.RegisterMessage(CurrentStatusRequest)

CurrentStatusResponse = _reflection.GeneratedProtocolMessageType('CurrentStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTSTATUSRESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.CurrentStatusResponse)
  })
_sym_db.RegisterMessage(CurrentStatusResponse)

GetProgressRequest = _reflection.GeneratedProtocolMessageType('GetProgressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROGRESSREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.GetProgressRequest)
  })
_sym_db.RegisterMessage(GetProgressRequest)

GetProgressResponse = _reflection.GeneratedProtocolMessageType('GetProgressResponse', (_message.Message,), {

  'RawPerChannel' : _reflection.GeneratedProtocolMessageType('RawPerChannel', (_message.Message,), {
    'DESCRIPTOR' : _GETPROGRESSRESPONSE_RAWPERCHANNEL,
    '__module__' : 'minknow.rpc.acquisition_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.GetProgressResponse.RawPerChannel)
    })
  ,
  'DESCRIPTOR' : _GETPROGRESSRESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.GetProgressResponse)
  })
_sym_db.RegisterMessage(GetProgressResponse)
_sym_db.RegisterMessage(GetProgressResponse.RawPerChannel)

GetAcquisitionRunInfoRequest = _reflection.GeneratedProtocolMessageType('GetAcquisitionRunInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACQUISITIONRUNINFOREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.GetAcquisitionRunInfoRequest)
  })
_sym_db.RegisterMessage(GetAcquisitionRunInfoRequest)

AcquisitionYieldSummary = _reflection.GeneratedProtocolMessageType('AcquisitionYieldSummary', (_message.Message,), {
  'DESCRIPTOR' : _ACQUISITIONYIELDSUMMARY,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.AcquisitionYieldSummary)
  })
_sym_db.RegisterMessage(AcquisitionYieldSummary)

ChannelStateInfo = _reflection.GeneratedProtocolMessageType('ChannelStateInfo', (_message.Message,), {

  'Style' : _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
    'DESCRIPTOR' : _CHANNELSTATEINFO_STYLE,
    '__module__' : 'minknow.rpc.acquisition_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ChannelStateInfo.Style)
    })
  ,

  'ChannelState' : _reflection.GeneratedProtocolMessageType('ChannelState', (_message.Message,), {
    'DESCRIPTOR' : _CHANNELSTATEINFO_CHANNELSTATE,
    '__module__' : 'minknow.rpc.acquisition_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ChannelStateInfo.ChannelState)
    })
  ,

  'Group' : _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
    'DESCRIPTOR' : _CHANNELSTATEINFO_GROUP,
    '__module__' : 'minknow.rpc.acquisition_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ChannelStateInfo.Group)
    })
  ,
  'DESCRIPTOR' : _CHANNELSTATEINFO,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ChannelStateInfo)
  })
_sym_db.RegisterMessage(ChannelStateInfo)
_sym_db.RegisterMessage(ChannelStateInfo.Style)
_sym_db.RegisterMessage(ChannelStateInfo.ChannelState)
_sym_db.RegisterMessage(ChannelStateInfo.Group)

AcquisitionConfigSummary = _reflection.GeneratedProtocolMessageType('AcquisitionConfigSummary', (_message.Message,), {
  'DESCRIPTOR' : _ACQUISITIONCONFIGSUMMARY,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.AcquisitionConfigSummary)
  })
_sym_db.RegisterMessage(AcquisitionConfigSummary)

AcquisitionRunInfo = _reflection.GeneratedProtocolMessageType('AcquisitionRunInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACQUISITIONRUNINFO,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.AcquisitionRunInfo)
  })
_sym_db.RegisterMessage(AcquisitionRunInfo)

ListAcquisitionRunsRequest = _reflection.GeneratedProtocolMessageType('ListAcquisitionRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACQUISITIONRUNSREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ListAcquisitionRunsRequest)
  })
_sym_db.RegisterMessage(ListAcquisitionRunsRequest)

ListAcquisitionRunsResponse = _reflection.GeneratedProtocolMessageType('ListAcquisitionRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACQUISITIONRUNSRESPONSE,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.ListAcquisitionRunsResponse)
  })
_sym_db.RegisterMessage(ListAcquisitionRunsResponse)

GetCurrentAcquisitionRunRequest = _reflection.GeneratedProtocolMessageType('GetCurrentAcquisitionRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTACQUISITIONRUNREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.GetCurrentAcquisitionRunRequest)
  })
_sym_db.RegisterMessage(GetCurrentAcquisitionRunRequest)

WatchCurrentAcquisitionRunRequest = _reflection.GeneratedProtocolMessageType('WatchCurrentAcquisitionRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHCURRENTACQUISITIONRUNREQUEST,
  '__module__' : 'minknow.rpc.acquisition_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.acquisition.WatchCurrentAcquisitionRunRequest)
  })
_sym_db.RegisterMessage(WatchCurrentAcquisitionRunRequest)



_ACQUISITIONSERVICE = _descriptor.ServiceDescriptor(
  name='AcquisitionService',
  full_name='ont.rpc.acquisition.AcquisitionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3892,
  serialized_end=4923,
  methods=[
  _descriptor.MethodDescriptor(
    name='start',
    full_name='ont.rpc.acquisition.AcquisitionService.start',
    index=0,
    containing_service=None,
    input_type=_STARTREQUEST,
    output_type=_STARTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='stop',
    full_name='ont.rpc.acquisition.AcquisitionService.stop',
    index=1,
    containing_service=None,
    input_type=_STOPREQUEST,
    output_type=_STOPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='watch_for_status_change',
    full_name='ont.rpc.acquisition.AcquisitionService.watch_for_status_change',
    index=2,
    containing_service=None,
    input_type=_WATCHFORSTATUSCHANGEREQUEST,
    output_type=_WATCHFORSTATUSCHANGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='watch_current_acquisition_run',
    full_name='ont.rpc.acquisition.AcquisitionService.watch_current_acquisition_run',
    index=3,
    containing_service=None,
    input_type=_WATCHCURRENTACQUISITIONRUNREQUEST,
    output_type=_ACQUISITIONRUNINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='current_status',
    full_name='ont.rpc.acquisition.AcquisitionService.current_status',
    index=4,
    containing_service=None,
    input_type=_CURRENTSTATUSREQUEST,
    output_type=_CURRENTSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_progress',
    full_name='ont.rpc.acquisition.AcquisitionService.get_progress',
    index=5,
    containing_service=None,
    input_type=_GETPROGRESSREQUEST,
    output_type=_GETPROGRESSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_acquisition_info',
    full_name='ont.rpc.acquisition.AcquisitionService.get_acquisition_info',
    index=6,
    containing_service=None,
    input_type=_GETACQUISITIONRUNINFOREQUEST,
    output_type=_ACQUISITIONRUNINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list_acquisition_runs',
    full_name='ont.rpc.acquisition.AcquisitionService.list_acquisition_runs',
    index=7,
    containing_service=None,
    input_type=_LISTACQUISITIONRUNSREQUEST,
    output_type=_LISTACQUISITIONRUNSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_current_acquisition_run',
    full_name='ont.rpc.acquisition.AcquisitionService.get_current_acquisition_run',
    index=8,
    containing_service=None,
    input_type=_GETCURRENTACQUISITIONRUNREQUEST,
    output_type=_ACQUISITIONRUNINFO,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACQUISITIONSERVICE)

DESCRIPTOR.services_by_name['AcquisitionService'] = _ACQUISITIONSERVICE

# @@protoc_insertion_point(module_scope)
