# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: minknow/rpc/instance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import acquisition_pb2 as minknow_dot_rpc_dot_acquisition__pb2
from . import device_pb2 as minknow_dot_rpc_dot_device__pb2
from . import protocol_pb2 as minknow_dot_rpc_dot_protocol__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='minknow/rpc/instance.proto',
  package='ont.rpc.instance',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1aminknow/rpc/instance.proto\x12\x10ont.rpc.instance\x1a\x1dminknow/rpc/acquisition.proto\x1a\x18minknow/rpc/device.proto\x1a\x1aminknow/rpc/protocol.proto\"\x17\n\x15GetVersionInfoRequest\"\x85\x03\n\x16GetVersionInfoResponse\x12H\n\x07minknow\x18\x01 \x01(\x0b\x32\x37.ont.rpc.instance.GetVersionInfoResponse.MinknowVersion\x12\x11\n\tprotocols\x18\x02 \x01(\t\x12\x1c\n\x14\x64istribution_version\x18\x03 \x01(\t\x12X\n\x13\x64istribution_status\x18\x04 \x01(\x0e\x32;.ont.rpc.instance.GetVersionInfoResponse.DistributionStatus\x1aK\n\x0eMinknowVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05\x12\x0c\n\x04\x66ull\x18\x04 \x01(\t\"I\n\x12\x44istributionStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STABLE\x10\x01\x12\x0c\n\x08UNSTABLE\x10\x02\x12\x0c\n\x08MODIFIED\x10\x03\"\x1d\n\x1bGetOutputDirectoriesRequest\"?\n\x11OutputDirectories\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\x0b\n\x03log\x18\x02 \x01(\t\x12\r\n\x05reads\x18\x03 \x01(\t\"$\n\"GetDefaultOutputDirectoriesRequest\")\n\x19SetOutputDirectoryRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x1c\n\x1aSetOutputDirectoryResponse\"(\n\x18SetReadsDirectoryRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x1b\n\x19SetReadsDirectoryResponse\"\xe0\x01\n\x17\x46ilesystemDiskSpaceInfo\x12\x15\n\rfilesystem_id\x18\x01 \x01(\t\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x12\x16\n\x0e\x62ytes_capacity\x18\x03 \x01(\x04\x12\x0c\n\x04what\x18\x04 \x03(\t\x12\x1d\n\x15\x62ytes_to_stop_cleanly\x18\x05 \x01(\x04\x12\x1f\n\x17\x62ytes_when_alert_issued\x18\x06 \x01(\x04\x12\x17\n\x0frecommend_alert\x18\x07 \x01(\x08\x12\x16\n\x0erecommend_stop\x18\x08 \x01(\x08\"\x19\n\x17GetDiskSpaceInfoRequest\"i\n\x18GetDiskSpaceInfoResponse\x12M\n\x1a\x66ilesystem_disk_space_info\x18\x01 \x03(\x0b\x32).ont.rpc.instance.FilesystemDiskSpaceInfo\"\x15\n\x13GetMachineIdRequest\"*\n\x14GetMachineIdResponse\x12\x12\n\nmachine_id\x18\x01 \x01(\t\"\x14\n\x12GetHostTypeRequest\"\xc0\x01\n\x13GetHostTypeResponse\x12\x41\n\thost_type\x18\x01 \x01(\x0e\x32..ont.rpc.instance.GetHostTypeResponse.HostType\"f\n\x08HostType\x12\x06\n\x02PC\x10\x00\x12\x14\n\x10PROMETHION_ALPHA\x10\x01\x12\x0b\n\x07GRIDION\x10\x02\x12\x13\n\x0fPROMETHION_BETA\x10\x03\x12\t\n\x05MINIT\x10\x04\x12\x0f\n\x0bMINION_MK1C\x10\x05\"\x1f\n\x1dStreamInstanceActivityRequest\"\x92\x01\n\nDeviceInfo\x12H\n\x0c\x64\x65vice_state\x18\x01 \x01(\x0e\x32\x32.ont.rpc.device.GetDeviceStateResponse.DeviceState\x12:\n\x0b\x64\x65vice_info\x18\x02 \x01(\x0b\x32%.ont.rpc.device.GetDeviceInfoResponse\"\xa9\x05\n\x1eStreamInstanceActivityResponse\x12\x33\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x1c.ont.rpc.instance.DeviceInfoH\x00\x12\x41\n\x0e\x66low_cell_info\x18\x02 \x01(\x0b\x32\'.ont.rpc.device.GetFlowCellInfoResponseH\x00\x12>\n\x11protocol_run_info\x18\x03 \x01(\x0b\x32!.ont.rpc.protocol.ProtocolRunInfoH\x00\x12G\n\x14\x61\x63quisition_run_info\x18\x04 \x01(\x0b\x32\'.ont.rpc.acquisition.AcquisitionRunInfoH\x00\x12[\n\x10\x66low_cell_health\x18\x05 \x01(\x0b\x32?.ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealthH\x00\x12\x45\n\ryield_summary\x18\x06 \x01(\x0b\x32,.ont.rpc.acquisition.AcquisitionYieldSummaryH\x00\x1a\xd1\x01\n\x0e\x46lowCellHealth\x12\x7f\n\x19\x63hannel_state_percentages\x18\x01 \x03(\x0b\x32\\.ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry\x1a>\n\x1c\x43hannelStatePercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x42\x0e\n\x0cstream_value2\x87\x08\n\x0fInstanceService\x12g\n\x10get_version_info\x12\'.ont.rpc.instance.GetVersionInfoRequest\x1a(.ont.rpc.instance.GetVersionInfoResponse\"\x00\x12n\n\x16get_output_directories\x12-.ont.rpc.instance.GetOutputDirectoriesRequest\x1a#.ont.rpc.instance.OutputDirectories\"\x00\x12}\n\x1eget_default_output_directories\x12\x34.ont.rpc.instance.GetDefaultOutputDirectoriesRequest\x1a#.ont.rpc.instance.OutputDirectories\"\x00\x12s\n\x14set_output_directory\x12+.ont.rpc.instance.SetOutputDirectoryRequest\x1a,.ont.rpc.instance.SetOutputDirectoryResponse\"\x00\x12p\n\x13set_reads_directory\x12*.ont.rpc.instance.SetReadsDirectoryRequest\x1a+.ont.rpc.instance.SetReadsDirectoryResponse\"\x00\x12n\n\x13get_disk_space_info\x12).ont.rpc.instance.GetDiskSpaceInfoRequest\x1a*.ont.rpc.instance.GetDiskSpaceInfoResponse\"\x00\x12\x61\n\x0eget_machine_id\x12%.ont.rpc.instance.GetMachineIdRequest\x1a&.ont.rpc.instance.GetMachineIdResponse\"\x00\x12^\n\rget_host_type\x12$.ont.rpc.instance.GetHostTypeRequest\x1a%.ont.rpc.instance.GetHostTypeResponse\"\x00\x12\x81\x01\n\x18stream_instance_activity\x12/.ont.rpc.instance.StreamInstanceActivityRequest\x1a\x30.ont.rpc.instance.StreamInstanceActivityResponse\"\x00\x30\x01\x62\x06proto3')
  ,
  dependencies=[minknow_dot_rpc_dot_acquisition__pb2.DESCRIPTOR,minknow_dot_rpc_dot_device__pb2.DESCRIPTOR,minknow_dot_rpc_dot_protocol__pb2.DESCRIPTOR,])



_GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS = _descriptor.EnumDescriptor(
  name='DistributionStatus',
  full_name='ont.rpc.instance.GetVersionInfoResponse.DistributionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSTABLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODIFIED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=475,
  serialized_end=548,
)
_sym_db.RegisterEnumDescriptor(_GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS)

_GETHOSTTYPERESPONSE_HOSTTYPE = _descriptor.EnumDescriptor(
  name='HostType',
  full_name='ont.rpc.instance.GetHostTypeResponse.HostType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMETHION_ALPHA', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GRIDION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMETHION_BETA', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINIT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINION_MK1C', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1369,
  serialized_end=1471,
)
_sym_db.RegisterEnumDescriptor(_GETHOSTTYPERESPONSE_HOSTTYPE)


_GETVERSIONINFOREQUEST = _descriptor.Descriptor(
  name='GetVersionInfoRequest',
  full_name='ont.rpc.instance.GetVersionInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=156,
)


_GETVERSIONINFORESPONSE_MINKNOWVERSION = _descriptor.Descriptor(
  name='MinknowVersion',
  full_name='ont.rpc.instance.GetVersionInfoResponse.MinknowVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='ont.rpc.instance.GetVersionInfoResponse.MinknowVersion.major', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='ont.rpc.instance.GetVersionInfoResponse.MinknowVersion.minor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patch', full_name='ont.rpc.instance.GetVersionInfoResponse.MinknowVersion.patch', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full', full_name='ont.rpc.instance.GetVersionInfoResponse.MinknowVersion.full', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=473,
)

_GETVERSIONINFORESPONSE = _descriptor.Descriptor(
  name='GetVersionInfoResponse',
  full_name='ont.rpc.instance.GetVersionInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minknow', full_name='ont.rpc.instance.GetVersionInfoResponse.minknow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocols', full_name='ont.rpc.instance.GetVersionInfoResponse.protocols', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distribution_version', full_name='ont.rpc.instance.GetVersionInfoResponse.distribution_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distribution_status', full_name='ont.rpc.instance.GetVersionInfoResponse.distribution_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETVERSIONINFORESPONSE_MINKNOWVERSION, ],
  enum_types=[
    _GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=548,
)


_GETOUTPUTDIRECTORIESREQUEST = _descriptor.Descriptor(
  name='GetOutputDirectoriesRequest',
  full_name='ont.rpc.instance.GetOutputDirectoriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=579,
)


_OUTPUTDIRECTORIES = _descriptor.Descriptor(
  name='OutputDirectories',
  full_name='ont.rpc.instance.OutputDirectories',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='ont.rpc.instance.OutputDirectories.output', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log', full_name='ont.rpc.instance.OutputDirectories.log', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reads', full_name='ont.rpc.instance.OutputDirectories.reads', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=644,
)


_GETDEFAULTOUTPUTDIRECTORIESREQUEST = _descriptor.Descriptor(
  name='GetDefaultOutputDirectoriesRequest',
  full_name='ont.rpc.instance.GetDefaultOutputDirectoriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=682,
)


_SETOUTPUTDIRECTORYREQUEST = _descriptor.Descriptor(
  name='SetOutputDirectoryRequest',
  full_name='ont.rpc.instance.SetOutputDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ont.rpc.instance.SetOutputDirectoryRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=725,
)


_SETOUTPUTDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='SetOutputDirectoryResponse',
  full_name='ont.rpc.instance.SetOutputDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=755,
)


_SETREADSDIRECTORYREQUEST = _descriptor.Descriptor(
  name='SetReadsDirectoryRequest',
  full_name='ont.rpc.instance.SetReadsDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ont.rpc.instance.SetReadsDirectoryRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=797,
)


_SETREADSDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='SetReadsDirectoryResponse',
  full_name='ont.rpc.instance.SetReadsDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=826,
)


_FILESYSTEMDISKSPACEINFO = _descriptor.Descriptor(
  name='FilesystemDiskSpaceInfo',
  full_name='ont.rpc.instance.FilesystemDiskSpaceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.filesystem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.bytes_available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_capacity', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.bytes_capacity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='what', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.what', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_to_stop_cleanly', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.bytes_to_stop_cleanly', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_when_alert_issued', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.bytes_when_alert_issued', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommend_alert', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.recommend_alert', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommend_stop', full_name='ont.rpc.instance.FilesystemDiskSpaceInfo.recommend_stop', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=1053,
)


_GETDISKSPACEINFOREQUEST = _descriptor.Descriptor(
  name='GetDiskSpaceInfoRequest',
  full_name='ont.rpc.instance.GetDiskSpaceInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1080,
)


_GETDISKSPACEINFORESPONSE = _descriptor.Descriptor(
  name='GetDiskSpaceInfoResponse',
  full_name='ont.rpc.instance.GetDiskSpaceInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filesystem_disk_space_info', full_name='ont.rpc.instance.GetDiskSpaceInfoResponse.filesystem_disk_space_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1187,
)


_GETMACHINEIDREQUEST = _descriptor.Descriptor(
  name='GetMachineIdRequest',
  full_name='ont.rpc.instance.GetMachineIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1189,
  serialized_end=1210,
)


_GETMACHINEIDRESPONSE = _descriptor.Descriptor(
  name='GetMachineIdResponse',
  full_name='ont.rpc.instance.GetMachineIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='ont.rpc.instance.GetMachineIdResponse.machine_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1254,
)


_GETHOSTTYPEREQUEST = _descriptor.Descriptor(
  name='GetHostTypeRequest',
  full_name='ont.rpc.instance.GetHostTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1276,
)


_GETHOSTTYPERESPONSE = _descriptor.Descriptor(
  name='GetHostTypeResponse',
  full_name='ont.rpc.instance.GetHostTypeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_type', full_name='ont.rpc.instance.GetHostTypeResponse.host_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETHOSTTYPERESPONSE_HOSTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1471,
)


_STREAMINSTANCEACTIVITYREQUEST = _descriptor.Descriptor(
  name='StreamInstanceActivityRequest',
  full_name='ont.rpc.instance.StreamInstanceActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1504,
)


_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='ont.rpc.instance.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_state', full_name='ont.rpc.instance.DeviceInfo.device_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_info', full_name='ont.rpc.instance.DeviceInfo.device_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1653,
)


_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY = _descriptor.Descriptor(
  name='ChannelStatePercentagesEntry',
  full_name='ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2321,
)

_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH = _descriptor.Descriptor(
  name='FlowCellHealth',
  full_name='ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_state_percentages', full_name='ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.channel_state_percentages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2112,
  serialized_end=2321,
)

_STREAMINSTANCEACTIVITYRESPONSE = _descriptor.Descriptor(
  name='StreamInstanceActivityResponse',
  full_name='ont.rpc.instance.StreamInstanceActivityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_info', full_name='ont.rpc.instance.StreamInstanceActivityResponse.device_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_cell_info', full_name='ont.rpc.instance.StreamInstanceActivityResponse.flow_cell_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_run_info', full_name='ont.rpc.instance.StreamInstanceActivityResponse.protocol_run_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acquisition_run_info', full_name='ont.rpc.instance.StreamInstanceActivityResponse.acquisition_run_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_cell_health', full_name='ont.rpc.instance.StreamInstanceActivityResponse.flow_cell_health', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yield_summary', full_name='ont.rpc.instance.StreamInstanceActivityResponse.yield_summary', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stream_value', full_name='ont.rpc.instance.StreamInstanceActivityResponse.stream_value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1656,
  serialized_end=2337,
)

_GETVERSIONINFORESPONSE_MINKNOWVERSION.containing_type = _GETVERSIONINFORESPONSE
_GETVERSIONINFORESPONSE.fields_by_name['minknow'].message_type = _GETVERSIONINFORESPONSE_MINKNOWVERSION
_GETVERSIONINFORESPONSE.fields_by_name['distribution_status'].enum_type = _GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS
_GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS.containing_type = _GETVERSIONINFORESPONSE
_GETDISKSPACEINFORESPONSE.fields_by_name['filesystem_disk_space_info'].message_type = _FILESYSTEMDISKSPACEINFO
_GETHOSTTYPERESPONSE.fields_by_name['host_type'].enum_type = _GETHOSTTYPERESPONSE_HOSTTYPE
_GETHOSTTYPERESPONSE_HOSTTYPE.containing_type = _GETHOSTTYPERESPONSE
_DEVICEINFO.fields_by_name['device_state'].enum_type = minknow_dot_rpc_dot_device__pb2._GETDEVICESTATERESPONSE_DEVICESTATE
_DEVICEINFO.fields_by_name['device_info'].message_type = minknow_dot_rpc_dot_device__pb2._GETDEVICEINFORESPONSE
_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY.containing_type = _STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH
_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH.fields_by_name['channel_state_percentages'].message_type = _STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY
_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH.containing_type = _STREAMINSTANCEACTIVITYRESPONSE
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['device_info'].message_type = _DEVICEINFO
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_info'].message_type = minknow_dot_rpc_dot_device__pb2._GETFLOWCELLINFORESPONSE
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['protocol_run_info'].message_type = minknow_dot_rpc_dot_protocol__pb2._PROTOCOLRUNINFO
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['acquisition_run_info'].message_type = minknow_dot_rpc_dot_acquisition__pb2._ACQUISITIONRUNINFO
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_health'].message_type = _STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['yield_summary'].message_type = minknow_dot_rpc_dot_acquisition__pb2._ACQUISITIONYIELDSUMMARY
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['device_info'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['device_info'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_info'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_info'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['protocol_run_info'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['protocol_run_info'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['acquisition_run_info'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['acquisition_run_info'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_health'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['flow_cell_health'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
_STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value'].fields.append(
  _STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['yield_summary'])
_STREAMINSTANCEACTIVITYRESPONSE.fields_by_name['yield_summary'].containing_oneof = _STREAMINSTANCEACTIVITYRESPONSE.oneofs_by_name['stream_value']
DESCRIPTOR.message_types_by_name['GetVersionInfoRequest'] = _GETVERSIONINFOREQUEST
DESCRIPTOR.message_types_by_name['GetVersionInfoResponse'] = _GETVERSIONINFORESPONSE
DESCRIPTOR.message_types_by_name['GetOutputDirectoriesRequest'] = _GETOUTPUTDIRECTORIESREQUEST
DESCRIPTOR.message_types_by_name['OutputDirectories'] = _OUTPUTDIRECTORIES
DESCRIPTOR.message_types_by_name['GetDefaultOutputDirectoriesRequest'] = _GETDEFAULTOUTPUTDIRECTORIESREQUEST
DESCRIPTOR.message_types_by_name['SetOutputDirectoryRequest'] = _SETOUTPUTDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['SetOutputDirectoryResponse'] = _SETOUTPUTDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['SetReadsDirectoryRequest'] = _SETREADSDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['SetReadsDirectoryResponse'] = _SETREADSDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['FilesystemDiskSpaceInfo'] = _FILESYSTEMDISKSPACEINFO
DESCRIPTOR.message_types_by_name['GetDiskSpaceInfoRequest'] = _GETDISKSPACEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetDiskSpaceInfoResponse'] = _GETDISKSPACEINFORESPONSE
DESCRIPTOR.message_types_by_name['GetMachineIdRequest'] = _GETMACHINEIDREQUEST
DESCRIPTOR.message_types_by_name['GetMachineIdResponse'] = _GETMACHINEIDRESPONSE
DESCRIPTOR.message_types_by_name['GetHostTypeRequest'] = _GETHOSTTYPEREQUEST
DESCRIPTOR.message_types_by_name['GetHostTypeResponse'] = _GETHOSTTYPERESPONSE
DESCRIPTOR.message_types_by_name['StreamInstanceActivityRequest'] = _STREAMINSTANCEACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.message_types_by_name['StreamInstanceActivityResponse'] = _STREAMINSTANCEACTIVITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetVersionInfoRequest = _reflection.GeneratedProtocolMessageType('GetVersionInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONINFOREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetVersionInfoRequest)
  })
_sym_db.RegisterMessage(GetVersionInfoRequest)

GetVersionInfoResponse = _reflection.GeneratedProtocolMessageType('GetVersionInfoResponse', (_message.Message,), {

  'MinknowVersion' : _reflection.GeneratedProtocolMessageType('MinknowVersion', (_message.Message,), {
    'DESCRIPTOR' : _GETVERSIONINFORESPONSE_MINKNOWVERSION,
    '__module__' : 'minknow.rpc.instance_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetVersionInfoResponse.MinknowVersion)
    })
  ,
  'DESCRIPTOR' : _GETVERSIONINFORESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetVersionInfoResponse)
  })
_sym_db.RegisterMessage(GetVersionInfoResponse)
_sym_db.RegisterMessage(GetVersionInfoResponse.MinknowVersion)

GetOutputDirectoriesRequest = _reflection.GeneratedProtocolMessageType('GetOutputDirectoriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOUTPUTDIRECTORIESREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetOutputDirectoriesRequest)
  })
_sym_db.RegisterMessage(GetOutputDirectoriesRequest)

OutputDirectories = _reflection.GeneratedProtocolMessageType('OutputDirectories', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTDIRECTORIES,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.OutputDirectories)
  })
_sym_db.RegisterMessage(OutputDirectories)

GetDefaultOutputDirectoriesRequest = _reflection.GeneratedProtocolMessageType('GetDefaultOutputDirectoriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTOUTPUTDIRECTORIESREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetDefaultOutputDirectoriesRequest)
  })
_sym_db.RegisterMessage(GetDefaultOutputDirectoriesRequest)

SetOutputDirectoryRequest = _reflection.GeneratedProtocolMessageType('SetOutputDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETOUTPUTDIRECTORYREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.SetOutputDirectoryRequest)
  })
_sym_db.RegisterMessage(SetOutputDirectoryRequest)

SetOutputDirectoryResponse = _reflection.GeneratedProtocolMessageType('SetOutputDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETOUTPUTDIRECTORYRESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.SetOutputDirectoryResponse)
  })
_sym_db.RegisterMessage(SetOutputDirectoryResponse)

SetReadsDirectoryRequest = _reflection.GeneratedProtocolMessageType('SetReadsDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREADSDIRECTORYREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.SetReadsDirectoryRequest)
  })
_sym_db.RegisterMessage(SetReadsDirectoryRequest)

SetReadsDirectoryResponse = _reflection.GeneratedProtocolMessageType('SetReadsDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETREADSDIRECTORYRESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.SetReadsDirectoryResponse)
  })
_sym_db.RegisterMessage(SetReadsDirectoryResponse)

FilesystemDiskSpaceInfo = _reflection.GeneratedProtocolMessageType('FilesystemDiskSpaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILESYSTEMDISKSPACEINFO,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.FilesystemDiskSpaceInfo)
  })
_sym_db.RegisterMessage(FilesystemDiskSpaceInfo)

GetDiskSpaceInfoRequest = _reflection.GeneratedProtocolMessageType('GetDiskSpaceInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISKSPACEINFOREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetDiskSpaceInfoRequest)
  })
_sym_db.RegisterMessage(GetDiskSpaceInfoRequest)

GetDiskSpaceInfoResponse = _reflection.GeneratedProtocolMessageType('GetDiskSpaceInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDISKSPACEINFORESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetDiskSpaceInfoResponse)
  })
_sym_db.RegisterMessage(GetDiskSpaceInfoResponse)

GetMachineIdRequest = _reflection.GeneratedProtocolMessageType('GetMachineIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMACHINEIDREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetMachineIdRequest)
  })
_sym_db.RegisterMessage(GetMachineIdRequest)

GetMachineIdResponse = _reflection.GeneratedProtocolMessageType('GetMachineIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMACHINEIDRESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetMachineIdResponse)
  })
_sym_db.RegisterMessage(GetMachineIdResponse)

GetHostTypeRequest = _reflection.GeneratedProtocolMessageType('GetHostTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTTYPEREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetHostTypeRequest)
  })
_sym_db.RegisterMessage(GetHostTypeRequest)

GetHostTypeResponse = _reflection.GeneratedProtocolMessageType('GetHostTypeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTTYPERESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.GetHostTypeResponse)
  })
_sym_db.RegisterMessage(GetHostTypeResponse)

StreamInstanceActivityRequest = _reflection.GeneratedProtocolMessageType('StreamInstanceActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINSTANCEACTIVITYREQUEST,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.StreamInstanceActivityRequest)
  })
_sym_db.RegisterMessage(StreamInstanceActivityRequest)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEINFO,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.DeviceInfo)
  })
_sym_db.RegisterMessage(DeviceInfo)

StreamInstanceActivityResponse = _reflection.GeneratedProtocolMessageType('StreamInstanceActivityResponse', (_message.Message,), {

  'FlowCellHealth' : _reflection.GeneratedProtocolMessageType('FlowCellHealth', (_message.Message,), {

    'ChannelStatePercentagesEntry' : _reflection.GeneratedProtocolMessageType('ChannelStatePercentagesEntry', (_message.Message,), {
      'DESCRIPTOR' : _STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY,
      '__module__' : 'minknow.rpc.instance_pb2'
      # @@protoc_insertion_point(class_scope:ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry)
      })
    ,
    'DESCRIPTOR' : _STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH,
    '__module__' : 'minknow.rpc.instance_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.instance.StreamInstanceActivityResponse.FlowCellHealth)
    })
  ,
  'DESCRIPTOR' : _STREAMINSTANCEACTIVITYRESPONSE,
  '__module__' : 'minknow.rpc.instance_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.instance.StreamInstanceActivityResponse)
  })
_sym_db.RegisterMessage(StreamInstanceActivityResponse)
_sym_db.RegisterMessage(StreamInstanceActivityResponse.FlowCellHealth)
_sym_db.RegisterMessage(StreamInstanceActivityResponse.FlowCellHealth.ChannelStatePercentagesEntry)


_STREAMINSTANCEACTIVITYRESPONSE_FLOWCELLHEALTH_CHANNELSTATEPERCENTAGESENTRY._options = None

_INSTANCESERVICE = _descriptor.ServiceDescriptor(
  name='InstanceService',
  full_name='ont.rpc.instance.InstanceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2340,
  serialized_end=3371,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_version_info',
    full_name='ont.rpc.instance.InstanceService.get_version_info',
    index=0,
    containing_service=None,
    input_type=_GETVERSIONINFOREQUEST,
    output_type=_GETVERSIONINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_output_directories',
    full_name='ont.rpc.instance.InstanceService.get_output_directories',
    index=1,
    containing_service=None,
    input_type=_GETOUTPUTDIRECTORIESREQUEST,
    output_type=_OUTPUTDIRECTORIES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_default_output_directories',
    full_name='ont.rpc.instance.InstanceService.get_default_output_directories',
    index=2,
    containing_service=None,
    input_type=_GETDEFAULTOUTPUTDIRECTORIESREQUEST,
    output_type=_OUTPUTDIRECTORIES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='set_output_directory',
    full_name='ont.rpc.instance.InstanceService.set_output_directory',
    index=3,
    containing_service=None,
    input_type=_SETOUTPUTDIRECTORYREQUEST,
    output_type=_SETOUTPUTDIRECTORYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='set_reads_directory',
    full_name='ont.rpc.instance.InstanceService.set_reads_directory',
    index=4,
    containing_service=None,
    input_type=_SETREADSDIRECTORYREQUEST,
    output_type=_SETREADSDIRECTORYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_disk_space_info',
    full_name='ont.rpc.instance.InstanceService.get_disk_space_info',
    index=5,
    containing_service=None,
    input_type=_GETDISKSPACEINFOREQUEST,
    output_type=_GETDISKSPACEINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_machine_id',
    full_name='ont.rpc.instance.InstanceService.get_machine_id',
    index=6,
    containing_service=None,
    input_type=_GETMACHINEIDREQUEST,
    output_type=_GETMACHINEIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_host_type',
    full_name='ont.rpc.instance.InstanceService.get_host_type',
    index=7,
    containing_service=None,
    input_type=_GETHOSTTYPEREQUEST,
    output_type=_GETHOSTTYPERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='stream_instance_activity',
    full_name='ont.rpc.instance.InstanceService.stream_instance_activity',
    index=8,
    containing_service=None,
    input_type=_STREAMINSTANCEACTIVITYREQUEST,
    output_type=_STREAMINSTANCEACTIVITYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESERVICE)

DESCRIPTOR.services_by_name['InstanceService'] = _INSTANCESERVICE

# @@protoc_insertion_point(module_scope)
