from unittest import TestCase





class TestPerformance(TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPerformanceOnNFiles(self, n=3000):
        pass